package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````4!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'`\C```/(P``#R,```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!(C```2(P```4`````$```
M`0```,"-``#`G0``P)T``(@"``"<`@``!@`````0```"````R(T``,B=``#(
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP(T`
M`,"=``#`G0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`.$Q5B>KVES>W\Y>'@I>:%-/7L7$!````!`````!
M````1TY5```````#`````@`````````1````2@````@````(`````9`0!"5`
M!(`H@``%H(90A("!``(+*`2,.(`208H```A*````2P```$X```!2````4P``
M`%P```!=````7@````````!@````80```&(```!C````9````&<`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R
M`8MOK$OCP$+ZUX?"Y3\L6.^7>;KCDGSZH6Q@F4_#FVL)0]9GK\QF0D75[(D'
M<-,S8MOM%8PES`TZEPM_J9R;X*<""FH:GE"_VE<;H^#[20``````````````
M````````````G!$````````#``L```````"@`````````P`6``0"````````
M`````!(```#D```````````````2````YP(`````````````$@```+("````
M`````````!(```"D`@`````````````2````E@``````````````$@```%T!
M`````````````!(```#Z```````````````2`````0``````````````(```
M`)T"`````````````!(````@`@`````````````2````*P$`````````````
M$@```!L!`````````````!(```"K`@`````````````2````#0$`````````
M````$@```-0!`````````````!(````0```````````````@````>P$`````
M````````$@```+H"`````````````!(```#I```````````````2````_P$`
M````````````$@```,$"`````````````!(````L```````````````@````
M1@``````````````$@```&,``````````````!8```!-`0`````````````2
M````=@``````````````$@```-,``````````````!(```"'````````````
M```2````\@$`````````````$@```-P!`````````````!(```#(`@``````
M```````2````RP,`````````````$@```+<``````````````!(```#W`@``
M```````````1````S0$`````````````$@```!$#`````````````!$````*
M`@`````````````2````/P$`````````````$@```,0!`````````````!(`
M``!P`@`````````````2````O0$`````````````$@```.X`````````````
M`!(```"K`0`````````````2````=`$`````````````$@```)4!````````
M`````!(```!0`@`````````````2````ZP$`````````````$@```/D!````
M`````````!(```#C`0`````````````2````_P(`````````````$@```*(`
M`````````````!(````9`@`````````````2````:`$`````````````$@``
M`#$"`````````````!(```#U`@`````````````1````@`(`````````````
M$0```,8``````````````!$```"S`0`````````````2````A@$`````````
M````$0```$("`````````````!(```#M`@`````````````2````-`$`````
M````````$@```#H"`````````````!(```!4```````````````2````7@(`
M````````````$@```(<"`````````````!(```#/`@`````````````2````
MI@$`````````````$@```-8"`````````````!(```".`@`````````````B
M````)@0``%R@````````$``7`-0#```D.0``/`$``!(`#0!+!```1"\``/0&
M```2``T`:P(``(`4``#0`@``$@`-`$L#``!D(0``!````!(`#0!I`P``.#8`
M`.P"```2``T`_`,``$B@````````$``7`'$$``!H(0``D`(``!(`#0`Q!```
M2*`````````0`!<`7`,``/@C```P````$@`-`'\#```8*P``H````!(`#0#@
M`P``1$H```0````1``\`"@0``(A'```P`0``$@`-`!4$``#T'P``7````!(`
M#0`=!```7*`````````0`!<`1@0``%R@````````$``7`%\$```4+@``,`$`
M`!(`#0"(!```N"L``'0````2``T`[P,```"@````````$``6`*,#```H)```
MK`$``!(`#0!8!```2*`````````0`!8`?@0``$2@```$````$0`6`/4#``!0
M%P```````!(`#0`]!```[$8``)P````2``T`\0,```"@````````(``6`+D#
M``#P+0``)````!(`#0"-`P``4"```!0!```2``T`KP,``+A(``!H`0``$@`-
M`"4$``!<H````````!``%P"0!```U"4``$0%```2``T``%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?
M8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S
M971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?
M9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O
M<&5N-C0`<W1R<F-H<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M
M9&ER`')E860`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`%]?;'-T870V
M-%]T:6UE-C0`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R
M:6YT9E]C:&L`7U]L:6)C7W-T87)T7VUA:6X`7U]S=&%T-C1?=&EM938T`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N-#``;&EB
M8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'
M3$E"0U\R+C0`1TQ)0D-?,BXS-``````````"``$``@`"``(``0`!``$``0`"
M``,``0`!``(``0`"``$``0`"``(``@`"``$``0`!``$``0`!``$``@`"``(`
M`@`!``(``@`$``(``0`"``,``@`!``(``@`"``(``@`"``(``@`!``(``0`"
M``(``@`!``(``0`"``(``0`"``$``P`"``(``@`"``(``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$````!``$`/0,``!`````@````%&EI#0``!`"=!`````````$``@`S`P``
M$`````````"TD98&```#`*<$```0````%&EI#0```@"=!````````,"=```7
M````Q)T``!<```#\GP``%P````2@```7````%*```!<````8H```%P```""@
M```7````)*```!<````HH```%P```"R@```7````,*```!<````XH```%P``
M`#R@```7````1*```!<```#(GP``%0H``,R?```5"P``T)\``!43``#4GP``
M%1D``-B?```3&P``W)\``!4<``#@GP``%1T``.2?```5)0``Z)\``!4G``#L
MGP``%3L``/"?```5/```])\``!4^``#XGP``%4D``-R>```6`P``X)X``!8$
M``#DG@``%@4``.B>```6!@``[)X``!8'``#PG@``%@@``/2>```6"0``^)X`
M`!8+``#\G@``%@P```"?```6#0``!)\``!8.```(GP``%@\```R?```6$```
M$)\``!81```4GP``%A(``!B?```6%```')\``!85```@GP``%A8``"2?```6
M%P``*)\``!88```LGP``%AH``#"?```6'@``-)\``!8?```XGP``%B```#R?
M```6(0``0)\``!8B``!$GP``%B,``$B?```6)```3)\``!8F``!0GP``%B@`
M`%2?```6*0``6)\``!8J``!<GP``%BL``&"?```6+```9)\``!8M``!HGP``
M%BX``&R?```6+P``<)\``!8P``!TGP``%C$``'B?```6,@``?)\``!8S``"`
MGP``%C0``(2?```6-0``B)\``!8V``",GP``%C<``)"?```6.```E)\``!8Y
M``"8GP``%CT``)R?```6/P``H)\``!9```"DGP``%D$``*B?```60@``K)\`
M`!9#``"PGP``%D0``+2?```610``N)\``!9&``"\GP``%D<``,"?```62```
MQ)\``!9)```(0"WI>P$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E&(T```#&C^((
MRHSB&/V\Y0#&C^((RHSB$/V\Y0#&C^((RHSB"/V\Y0#&C^((RHSB`/V\Y0#&
MC^((RHSB^/R\Y0#&C^((RHSB\/R\Y0#&C^((RHSBZ/R\Y0#&C^((RHSBX/R\
MY0#&C^((RHSBV/R\Y0#&C^((RHSBT/R\Y0#&C^((RHSBR/R\Y0#&C^((RHSB
MP/R\Y0#&C^((RHSBN/R\Y0#&C^((RHSBL/R\Y0#&C^((RHSBJ/R\Y0#&C^((
MRHSBH/R\Y0#&C^((RHSBF/R\Y0#&C^((RHSBD/R\Y0#&C^((RHSBB/R\Y0#&
MC^((RHSB@/R\Y0#&C^((RHSB>/R\Y0#&C^((RHSB</R\Y0#&C^((RHSB:/R\
MY0#&C^((RHSB8/R\Y0#&C^((RHSB6/R\Y0#&C^((RHSB4/R\Y0#&C^((RHSB
M2/R\Y0#&C^((RHSB0/R\Y0#&C^((RHSB./R\Y0#&C^((RHSB,/R\Y0#&C^((
MRHSB*/R\Y0#&C^((RHSB(/R\Y0#&C^((RHSB&/R\Y0#&C^((RHSB$/R\Y0#&
MC^((RHSB"/R\Y0#&C^((RHSB`/R\Y0#&C^((RHSB^/N\Y0#&C^((RHSB\/N\
MY0#&C^((RHSBZ/N\Y0#&C^((RHSBX/N\Y0#&C^((RHSBV/N\Y0#&C^((RHSB
MT/N\Y0#&C^((RHSBR/N\Y0#&C^((RHSBP/N\Y0#&C^((RHSBN/N\Y0#&C^((
MRHSBL/N\Y0#&C^((RHSBJ/N\Y0#&C^((RHSBH/N\Y0#&C^((RHSBF/N\Y0#&
MC^((RHSBD/N\Y0#&C^((RHSBB/N\Y0#&C^((RHSB@/N\Y0#&C^((RHSB>/N\
MY0#&C^((RHSB</N\Y0#&C^((RHSB:/N\Y0#&C^((RHSB8/N\Y0#&C^((RHSB
M6/N\Y0#&C^((RHSB4/N\Y0#&C^((RHSB2/N\Y0'*H.-P0"WI#,!-X,@/C.5@
MPI_E8#*?Y2C03>(,P(_@'`"-Y1@0C>44((WE`S"<YQ@0C>(4((WB'`"-XCQ"
MG^4`,)/E)#"-Y0`PH./6___K+"*?Y01`C^`H,I_E`B"4YPP@C>4#,)3G`A"@
MX0,`H.$0,(WE2PT`ZPPRG^4#,)3G`%#3Y0``5>-1```*_#&?Y4(-`.L#,)_G
M'%"=Y0,@D.<$`(7BUC/2Y0<!<.,#,(/C`U"%XM8SPN5B``"*``&@X:3__^O(
M$9_ER"&?Y0$0C^`"((_@`,"1Y1Q`G>48$)WE`0!4XP#@D>4`,*#A!`""Y:0!
MG^6D(9_E``"/X`(@C^``X(/E`1"#Z0P@@^54``#:!`!!X@S`@^($`8#@!."Q
MY03@K.4!`%#A^___&@-`A.)L89_E`!"@XP9@C^`$$8/G#`"6Y0`0C>58$9_E
M!2"@X0$0C^`*___K``!0XRD```I$49_E(&"-X@50C^`,`)7E2___ZP80H.$`
M0*#A+`&?Y0``C^"K``#K``!0XR````H<,9_E`S"/X`P`D^7I_O_K(?__ZPPA
MG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]
MZ`7__^O<()_E`B"/X```4.,,`(+E'P``"A3__^O(,)_EZ0P`ZP,PG^<#,)#G
MAE;#Y:#__^H,`);EZ/[_Z]+__^H(`)7E``!0XP$```J?"`#KV?__ZI0`G^4&
M$*#A``"/X'\``.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)3G``"/X`,0
MH.$,,(WE-O__ZP1`H..P___J`0"@XUG__^L?___K+(H``!@!``#TB0``^```
M`!`!```@`0``O(H``/"*``#TB@``>#@``'@X``",B@``;`D``%R*``"4-0``
M,(H``)R(``#HB0``6(D``(`T```D`0``7#8```"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<K___KD?[_ZT2'
M```L`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!E_[_ZBR'``#\````+`"?
MY2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!
M$_\OX8"(``!\B```^(8````!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#
M$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A/(@``#B(
M``"HA@``!`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E$$`M
MZ0,PDN<``%/C`@``"B@PG^4#`)_G^O[_Z\K__^L<,)_E`2"@XP,PC^``(,/E
M$("]Z.R'``!LA@``*`$``'R'``"LAP``T/__Z@'*H./P1RWI#,!-X.`/C.6\
M,)_EO""?Y0,PC^`"()/G`)"2Y0``6>,G```*`%#0Y0"`H.$``%7C/0!5$P%P
MH.$!4*`3`%"@`Q$``!H`0)GE``!4XPP```H)8*#A!2"@X0@0H.$$`*#AN/[_
MZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@`4*#A
M`3#UY0``4^,]`%,3^___&@A01>#F___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`
M8(?E\(>]Z`E`H.'M___J^(4``!0!```!RJ#C$$`MZ0S`3>"`#XSEC""?Y8PP
MG^4"((_@>-!-X@,PDN<-$*#A`$"@X0`PD^5T,(WE`#"@XQ7^_^L``%#C``"@
M$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`()/E
M=#"=Y0(@,^``,*#C!P``&GC0C>(0@+WH`A"@XP0`H.$=_O_K$`]OX:`"H.'N
M___J3_[_ZQR%```8`0``T(0```'*H./P0"WI#,!-X&@/C.5<(9_E7#&?Y0(@
MC^`#,)+GA-!-X@!@4.(`,)/E?#"-Y0`PH.,"```*`##6Y0``4^,*```:,"&?
MY2@QG^4"((_@`S"2YP`@D^5\,)WE`B`SX``PH.-!```:A-"-XO"`O>C)_?_K
M`$!0XO'__PH$`*#A2?[_ZP``4.,J```*$S#0Y1-0@.(N`%/C`@``&@$PU>4`
M`%/C]/__"A,PT.4N`%/C)0``"@8`H.'S_?_K`'"@X04`H.'P_?_K``"'X`(`
M@.(4_O_KI#"?Y0`@X.,#,(_@`1"@XP10C>4`8(WE`'"@X3#^_^L($(WB!P"@
MX?W]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2```*W?W_ZP<`H.'&_?_K
M!`"@X1[^_^L``%#CU/__&@0`H.'J_?_K!@"@X0/^_^N]___J`3#5Y2X`4^/6
M__\:`C#5Y0``4^/%__\*TO__ZJ3__^OK___J[_W_ZVR$```8`0``.(0``+`O
M```!RJ#C\$<MZ0S`3>#8#XSE`##1Y1`BG^4]`%/C##*?Y0(@C^`!0*#A`S"2
MYP%`@0((T$WB`%"@X00`H.$`,)/E!#"-Y0`PH..N_?_K#1"@X=R!G^4(@(_@
M`&"@X04`H.$B___K`)!0XD````JE_?_K``!6X3<``)JX,9_E`'"=Y0.`F.<'
M<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@\^4``%+C/0!2$_O_
M_QH%,$/@`@"&X@,`@.``8)CEMOW_ZP``4.,'`(;G%0``"@`@F.4%`*#A`3#0
MY`<0DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"$*#A``!3XST`4Q,!,,+D
M^?__&CTPH.,!(*#A`##!Y0$PU.0!,.+E``!3X_O__QH((9_E^#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]Z`&02>(!,-3D`3#IY0``
M4^/[__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C)```"@<PH.$$(+/E"1"@
MX0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``()/E``!2XP\``!H!(*#C
M`0"@X0`@@^5U_?_K`*!0XM7__PH'$*#A"7&@X0<@H.%^_?_K`*"(Y0`PH.,`
MD(WE`9")X@DQBN>B___J!P"@X93]_^L``%#C`*"@X0``B.7%__\*"7&@X?+_
M_^H#D*#A"!"@X]___^I@_?_KX((``!@!``"L@@``%`$``,R!``#0@@```<J@
MX_!!+>D,P$W@``",Y2``#.4!<*#A_!"?Y0':3>+X,)_E"-!-X@$0C^`#,)'G
M`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CU`"?Y02`C>+0()_E``"/X`@0H.%=
M_?_K`$!0X@8``-H!,$3B`\"-X`0@W.4``%+C%P``&@``4^,4```:H#"?Y>$*
M`.L#,)_G!R"@X0,`D.<&$*#AZOS_ZX@@G^5T,)_E`B"/X`$:C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.,2```:`=J-X@C0C>+P@;WH`T"@X00@H.$O$*#C
M"`"@X5+]_^L``%#CX___"C@PG^7%"@#K`S"?YP@@H.$#`)#G!A"@X00PH.'W
M_/_KX?__ZA/]_^N4@```&`$``'@L``#_#P``.($``!2```#(@````<J@XQ!`
M+>D,P$W@Z`^,Y700G^5T,)_E`1"/X'`@G^40T$WB`S"1YPPPC>4"()_G8#"?
MY6`0G^6G"@#K`S"/X`!`H.$!$(_@`@"0YPP@G>4>_?_K1`"?Y40PG^4``)_G
M0""?Y4`0G^4#,(_@`,"@XP``E.<"((_@`1"/X`@0C>B[_/_K$-"-XA"`O>AL
M?P``#`$``&"````0;```8"L``#"```!`+@``>!8``$@K```00"WIB`H`ZSA`
MG^4X()_E!$"/X#0PG^4(T$WB`B"4YP0@C>4#,)_G)!"?Y0,`D.<@,)_E`1"/
MX`,PC^`(T(WB$$"]Z/7\_^K$?@``#`$``+A_``#`*@``9&L```'*H.-P0"WI
M#,!-X```C.4!RDSB``",Y2@`#.78()_E`MI-XM0PG^48T$WB`B"/X`,PDN<"
M&HWB%!"!X@`PD^4`,('E`#"@X\O\_^NPP)_EL#"?Y0S`C^`,0(WB`6J-XJ0@
MG^4#,(_@`1"@XQ!@AN(!$(WH!`"@X<O\_^L$`*#A`2J@XP80H.'!_/_K`$!0
MX@!0H+,(``"Z`0"$XI[\_^L`4%#B!```"@0@H.$&$*#A>/S_ZP`PH.,$,,7G
M3""?Y3@PG^4"((_@`AJ-X@,PDN<4$('B`""3Y0`PD>4"(#/@`#"@XP,``!H%
M`*#A`MJ-XAC0C>)P@+WHBOS_ZTQ^```8`0``A"H``&@J```!$```M'T``+G_
M_^H!RJ#C\$\MZ0S`3>```(SEL``,Y40BG^5"W4WB0#*?Y0S03>("((_@`&"@
MX30"G^4#,)+G0LV-XA"`C>(!0*#A``"/X`@0H.$$P(SB`#"3Y0`PC.4`,*#C
MO/W_ZR\0H.,`4*#A!@"@X1'\_^L``%#C$@``"O`!G^4&$*#A``"/X';^_^L&
M`*#AX"&?Y=`QG^4"((_@0AV-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XVD`
M`!I"W8WB#-"-XO"/O>@$`*#A1?S_ZZ01G^4!$(_@5/S_ZP!`4.+E__\*`##4
MY9"1G^6(H(WB``!3XPF0C^`$<$KB.P``"@``5>,$```*!!"@X04`H.%V_/_K
M``!0XRL```H$`*#A$OS_ZP$P0.(#,(3@`P!4X0"PH.$`,(0P`!"@,P$`A#(#
M```Z"```Z@,`4.$`$,/E`@``"@$@<^4O`%+C^?__"@0`H.$!_/_K`+"@X08`
MH.'^^__K"P"`X`$`@.(!"E#CO?__*O@`G^4),*#A``"/X`$JH.,!$*#C00"-
MZ0!`C>4'`*#A//S_ZP@0H.$'`*#A"?S_ZP``4.,#```::#`:Y0\Z`^(""5/C
M%0``"K00G^4``*#C`1"/X!3\_^L`0%#BI?__"@`PU.4``%/CP___&@``5>,6
M```*`##5Y2X`4^,#```*@$"?Y0&PH.,$0(_@U?__Z@$PU>4``%/CZO__"O?_
M_^H!$*#C!P"@X</[_^L``%#CY/__&E``G^4'$*#A``"/X`?^_^L'`*#AY?O_
MZX[__^HX0)_E`;"@XP1`C^#!___JZ_O_ZSQ]```8`0``B"D``%@I``#0?```
M&"D``/PH``!L*```&"@``,`G``"<)P``<"<```'*H.,00"WI#,!-X/@/C.4O
M$*#C`$"@X9/[_^L``%#C`4"`$@0`H.$00+WHQ_O_Z@'*H.-P0"WI#,!-X```
MC.48``SE="&?Y0':3>)P,9_E"-!-X@(@C^`!&HWB`S"2YP!@4.($$('B`#"3
MY0`P@>4`,*#C+P``"@`PUN4``%/C+```"I/[_^L!((#B`0I2XP!`H.$X``"*
M!%"-X@80H.$%`*#AD?O_ZP$P1.(#,(7@!0!3X0<``)H`$*#C`@``Z@,`5>$!
M$,/E`@``"@$@4^0O`%+C^?__"B\0H.,%`*#A8?O_ZP``4.,E```*!0!0X0`P
MH(,`,,"%!0"@X9/[_^O`()_EN#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1
MY0(@,^``,*#C(P``&@':C>((T(WB<("]Z(P@G^6`,)_E`B"/X`$:C>(#,)+G
M!!"!X@`@D^4`,)'E`B`SX``PH.,5```:9`"?Y0``C^`!VHWB"-"-XG!`O>AT
M^__J``"@X][__^I(()_E-#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@
M,^``,*#C`@``&B``G^4``(_@Z___ZF_[_^M\>@``&`$``,AY``"0>0``S"4`
M`$1Y``"`)0```<J@XW!`+>D,P$W@Z`^,Y<0DG^7$-)_E`B"/X,!DG^4#,)+G
M"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50C^`$$*#A!@"@X:3\_^L`
M`%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@!!"@X08`H.&._/_K``!0
MXPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00H.$&`*#A>/S_ZP``4.,.
M```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A!@"@X6+\_^L``%#C#@``
M"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`H.%,_/_K``!0XPX```HL
M,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A-OS_ZP``4.,.```*U#*?
MY0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X2#\_^L``%#C#@``"GPRG^4`
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.$*_/_K``!0XPX```HD,I_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^H(8I_E!F"/X`00H.$&`*#A]/O_ZP``4.,.```*S#&?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___JM&&?Y09@C^`$$*#A!@"@X=[[_^L``%#C#@``"G0QG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZF!AG^4&8(_@!!"@X08`H.'(^__K``!0XPX```H<,9_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^H,`9_E!!"@X0``C^"S^__K`!!0X@(```KX`)_E``"/X'+\_^OP`)_E!!"@
MX0``C^"J^__K`!!0X@(```K<`)_E``"/X&G\_^O4`)_E!!"@X0``C^"A^__K
M`!!0XA(```K``)_E``"/X&#\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>A0_/_JA`"?Y000
MH.$``(_@B/O_ZP`04.+I__\*<`"?Y0``C^!'_/_KY?__ZC'Z_^O<>```&`$`
M`%PE``"T>```%`$``/PD``"L)```8"0``!`D``#((P``#",``"0C``#8(@``
MC"(``+@A``#D(0``N"$``-0A``#4(0``T"$``/0@``!\=```K"$``!`A``!\
M(0```"$```'*H.,$X"WE#,!-X/`/C.5X()_E>#"?Y0(@C^!T`)_E#-!-X@,P
MDN<``(_@#1"@X0`PD^4$,(WE`#"@XU?[_^L``%#C!0``"@``T.4``%#C,`!0
M$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C
M`0``&@S0C>($\)WD\_G_ZYAS```8`0``8"```$AS```!RJ#C#P`MZ03@+>4,
MP$W@\`^,Y4@`G^5($)_E``"/X`$0D.=`P)_E#-!-XCP@G^4,P(_@`!"1Y000
MC>4`$*#C%#"-X@`PC>4"$)SG$""=Y0``D>4!$*#CP/G_Z_\`H.,/^O_K]'(`
M`!@!``#@<@``'`$```#`H./P0RWI`>B@XPS`3>`.X$S@`<I,X@``C.4.`%SA
M^___&C@`#N4!V$WB'-!-X@(0H.-LP9_E`!"-Y6@1G^4,P(_@`1"<YP'HC>(`
M(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`@*#AL?G_ZP%@4.(`<,'BQR^@X<<_
M)N`",%/@`SB@X2,XH.$","/@`C!3X`(@PN`#8%;@`G#'X```5^,V``"Z#%"-
MX@`0H.,&(*#A!S"@X0@`H.$`$(WEG/G_ZP$`<>,!`'`#,@``"MP@G^4%$*#A
M"`"@X6+Y_^L!`'#C*0``"@<`4.,?``":"`!`X@!`E>`<```JM)"?Y0F0C^`"
M``#J`4!$X@4`5.$6```Z"""@XPD0H.$$`*#A)_G_ZP``4./V__\:!4!$X`8`
ME.#$'Z?@?""?Y6PPG^4"((_@`<B-X@,PDN<4P(SB`""3Y0`PG.4"(#/@`#"@
MXQ```!H!V(WB'-"-XO"#O>@!:%;B`'#'X@$`=^,!"'8#R?__&@``X.,`$*#A
MZ?__ZB@`G^4``(_@?/__ZR``G^4``(_@>?__ZVCY_^M<<@``&`$```@``0#8
M<@``8'$``'0>``!8'@```<J@XQ!`+>D,P$W@^`^,Y1WY_^LZ^?_K``!0XP``
MD!40@+WH`<J@X_!`+>D,P$W@T`^,Y?@@G^7X8)_E^#"?Y0(@C^`<T$WB`S"2
MYP9@C^``4*#A$!"-X@8`H.$`,)/E%#"-Y0`PH..6^O_K`$!0X@(```H`,-3E
M``!3XPX``!JX()_EL#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XR(``!J8
M`)_E!1"@X0``C^`<T(WB\$"]Z$;[_^H%`*#A!OG_ZP!PH.$$`*#A`_G_ZP``
MA^`"`(#B)_G_ZV0PG^4`(.#C`S"/X!@`C>E8,)_E`1"@XP,PC^``4(WE`'"@
MX4'Y_^M$()_E+#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XP<0H`$&`*`!
MW___"A3Y_^N8<````!X``!@!``!0<```H!T``'@<``!L'```S&\```'*H./P
M3RWI#,!-X.`.C.50QI_E`*"@X0S`C^`,,(SB!P"3Z/S03>*0<(WB!P"'Z#0F
MG^4T-I_E`B"/X`,PDN<88(SB`#"3Y?0PC>4`,*#C#P"VZ*A`C>($X*#A#P"N
MZ`,`EN@PP(SB`P".Z`<`G.B<4(WB!P"%Z/0%G^4@@(WB``"/X`@0H.$Y^O_K
MY+6?Y0NPC^``8%#B`@``"@`PUN4``%/C&`$`&J+X_^N_^/_K``!0XWH```H`
M8)#E``!6XW<```H&`*#AK_C_ZX``H.$!`(#BT_C_ZP`0UN4``%'C`%"@X1P`
MC>4+```*B)6?Y0F0C^`%`*#A`!"-Y0DPH.$!$*#C`"#@X^KX_^L!$/;E`E"%
MX@``4>/U__\:7`6?Y0``C^`"``#J!`"TY0``4.,-```*"!"@X0WZ_^L`4%#B
M^/__"@`PU>4``%/C]?__"C[Z_^L``%#C\O__"@4`H.&G^/_K`$!0X@T``!H$
M0)?D``!4XPH```H`,-3E``!3X]````H$`*#A,/K_ZP``4./U__\*!`"@X9GX
M_^L`0%#B\?__"@0`H.%W^/_K'&"=Y0!PH.$&`*#A<_C_ZP!PA^`!>X?B!'"'
MX@<`H.&5^/_KK#2?Y0`@X.,#,(_@"#"-Y:`TG^4!$*#C`S"/X`0PC>64-)_E
M#&"-Y0,PC^``0(WE`%"@X:OX_^L'':#C!0"@X1CX_^L!`'#C`P``&L#X_^L`
M$)#E$0!1XZP``!H($*#A!0"@X2KX_^L`8%#B+0``"D@DG^4`,)KE`A";YT`D
MG^4``)'E`B"/X`$0H.,`4(WE=OC_ZP!PH.,H))_E_#.?Y0(@C^`#,)+G`""3
MY?0PG>4"(#/@`#"@X_(``!H'`*#A_-"-XO"/O>A9^/_K`&!0XHH``!H$`)7D
M``!0XPD```H($*#AKOG_ZP`P4.+X__\*`##3Y0``4^/R__\:!`"5Y```4./U
M__\:#0"@XU'X_^NT8Y_E4Q"@XP9@C^``4*#A'`"-Y7S__^HP,)WE#SH#X@$)
M4^/-__\:.$"=Y0GX_^L``%3AR?__&C`PG>6#.Z#AHSN@X0<-4^/$__\:!P"@
MX3SX_^L($*#A`'"@X5P#G^4``(_@BOG_ZP`04.)\```*``":Y;+[_^L`D%#B
M>```"@D`H.$(^/_K`P!0XP!`H.$,``":*!.?Y00`0.(``(G@`1"/X&#X_^L`
M`%#C!0``&@0`5..@```*!$")X`4P5.4O`%/CG```"O@"G^4($*#A``"/X&[Y
M_^L``%#C`P``"@`PT.4P`%/C``!3$P0``!H`$*#C"0"@X?KW_^L`0%#B60``
M&L`2G^7``I_E`1"/X```C^`B^O_K(OC_Z[`RG^6P(I_E`S"/X`PPC>6H,I_E
M`B"/X*2BG^6DDI_EI(*?Y00@C>4#,(_@`"#@XP$0H.,`4(WE"J"/X`F0C^`(
M@(_@"`"-Y0<`H.$:^/_K#@``ZC/X_^L`,)#E$0!3XQ```!H(^/_K`1"@XP%@
MAN`*,*#A!""@X1"0C>4,8(WE`,"@X2`1C>@'`*#A"OC_ZP<=H.,'`*#A=_?_
MZP$`<.,`0*#AZO__"@4`H.&E]__K&`*?Y0<0H.$``(_@\?G_ZP<`H.&"_O_K
M9___Z@-`H.$T___JK??_ZX``H.$!`(#B_/[_ZJ@AG^4`,)KE`@";Y]PAG^4`
M`)#E`B"/X`00C>4`4(WE`1"@X\WW_^M5___J;_[_Z[PAG^54,9_E`B"/X`,P
MDN<`()/E]#"=Y0(@,^``,*#C2```&@8`H.'\T(WB\$^]Z*_W_^H`D)KEA/__
MZN7]_^L`D%'B`("@X:'__[H*(%#B`*"@XP`PR>($`*#AP+"-X@"@C>6H]__K
M!B"@XPL0H.$$`*#A<??_ZP8`4.,R```:0#&?Y<`@G>4#`%+AD/__&K0@V^$P
M,9_E`P!2X8S__QHR(%CB`##)X@0`H.'(8(WB`*"-Y93W_^LH(*#C!`"@X080
MH.%=]__K*`!0XQX``!KX,)_E`"#@XP,PC^`,,(WE[#"?Y0$0H.,#,(_@2`"-
MZ>`PG^4'`*#A`S"/X`!0C>7PH,WEI_?_ZZ'__^H$0)KE``!4XU___PH$`*#A
M5O?_ZP,`4.-;__^:K!"?Y00`0.(``(3@`1"/X*_W_^L``%#C!)"@`5/__^IU
M]__KC`"?Y0``C^""_?_KI'```$QO```8`0``;!L``/1N```@'```B!L``$P;
M```L&@``(!L``!P!```4&P``%&T``"`:``!\&@``1!H``*P8``#L&```;!@`
M`*0:```$&```S!D``,P9``!P&@``V!<``#@7```X&```;&H```!#04-(10``
MP!@``!P6``#8%P``B!<``'07```!RJ#C<$`MZ0S`3>#H#XSE=!*?Y70BG^4!
M$(_@`B"1YPC03>)H,I_E`""2Y00@C>4`(*#C`S"?Y^H$`.L#0)#G4`*?Y6@P
MU.4``(_@:3#$Y0T0H.&)^/_K#5"@X0``4.,"```*`##0Y3$`4^-M```*R?O_
MZR`RG^7:!`#K`S"?YP-`D.<4$I_E!`"@X0$0C^`#,*#C`2"@X]KV_^L`0%#B
M#@``"A`@E.7T,9_E`!"2Y0,PG^?L(9_ER@0`ZP(@C^``8*#A`P"0Y]3V_^L0
M,)3E`!"3Y0@PD>4!!1/C7```&L0QG^7$$9_E`S"?Y[T$`.L!(*#C`&"@X0$0
MC^`#`)#G`S"@X[_V_^L`0%#B"P``"IP!G^4%$*#A``"/X%?X_^L0,)3E`!"3
MY0`@4.)!```*@#&?Y0,PG^<#`);GM_;_ZW0QG^6G!`#K`S"?YVP1G^4#8)#G
M`$"@X0$0C^`!(*#C!@"@X97V_^M4(9_E`B"/X``0H.$&`*#AJ/;_ZT0QG^5$
M`9_E`S"?YP`@H.,#,)3G!1"@X0``C^!I(,/E-_C_ZRA1G^4%4(_@``!0XP!`
MH.$(`(7E$@``"@<=H.,$`*#A;_;_ZP$@@.(1`%#C`0!2$P`PH.$D``"*]""?
MY:PPG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,:```:"-"-XG"`O>@$`)7E
MO_W_ZP``4.,`0*#A"`"%Y>;__QJT`)_E``"/X-?V_^L!,-#E``!3XY/__PJ-
M___JG#"?Y0$`H.$#,(_@!#"3Y0`0D^5@^?_KNO__ZH0PG^4#,)_G`P"6YZWV
M_^N=___JM/;_ZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.&^]O_K>&@`
M`!@!``!D:0``!!4``!QI``"4%@``Z&@``&@6``"P:```-!8``.P3``!D:```
M4&@``-@5``#<%0``%&@``&03``!H:```L&8``#`5``#,9P``0&<``)AG``#X
M%````<J@XS!`+>D,P$W@Z`^,Y0PAG^4,,9_E`B"/X`!`H.$$`9_E`S"2YPS0
M3>(-$*#A``"/X``PD^4$,(WE`#"@X]/W_^L`,%#B"@``"@`PT^4P`%/C``!3
M$P$PH`,`,*`3`3`CX@``5.,`,*`#`3`#$@``4^,*```:L""?Y:0PG^4"((_@
M`S"2YP`@D^4$,)WE`B`SX``PH.,@```:#-"-XC"`O>@`,-3E``!3X_'__PH$
M`*#ADOK_ZR\0H.,`4*#A'O;_ZP``4.,!4(`2!0"@X5/V_^M8$)_E!""@XP$0
MC^!_]O_K``!0X^+__QI$()_E,#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@
MXP,``!H$`*#A#-"-XC!`O>C_]__J2_;_ZXQE```8`0``3!(``"1E``!H$@``
ML&0```'*H./P3RWI#,!-X$`-C.58[)_E6#R?Y0[@C^"GWTWB`S">YQ`@C>(`
M$*#A0,"`XH!0@.(`,)/EE#*-Y0`PH.,"`*#A`$"@XP1@'.4(<!SE)C2@X6?H
M)^#_/`/B)CR#X2[DH.$&A*#A!CR#X?_LSN/_:`CB",",XF?D+N`&,(/A#`!5
MX0#@@.4$0(#E"#"`Y0Q`@.40`(#BZO__&H(_@N($,(WEB#"=Y1C@C>(($(WE
M>("=Y7P@G>48H)WE@'"=Y81@G>6,P)WE$%"=Y11`G>4<D)WE#@"@X0,0H.$,
MX(WE`0``Z@N@H.$#D*#A/."0Y0`0C>4X$)#E"+"PY0`PH.-T,(#E!#"0Y0L0
M(>`($"'@`^`NX`40(>`"X"[@!.`NX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!
MX03`G>4'@*#A#`!0X0!PG>4*4*#A"4"@X0#`H.-P$(#EX?__&@@0G>4,X)WE
M`("1Y0@[G^4!")'I""`>Y2!`D>6H;:#A$'"1Y1B0D>4#()+@@&*&X00@DN"(
M8H;A#,"1Y0)@EN`)("?@*U&@X0L@`N`)("+@#%^%X0)@EN`+7X7A&""=Y2C!
MH.$`SXSA!0`GX`,@DN`(``#@"2"2X`<`(.`(SXSA``"2X`@@GN4,0"7@`R"2
MX`9`!.`%0"3@!R"2X.8-@.`$()+@X$V"X!`@GN4#()+@!2"2X&91+.``4`7@
M#%`EX`4@DN`84)[E8`&@X0-0E>`,P)7@9E$@X`10!>!F427@Y"V"X`7`G.#B
M78S@(,">Y0/`G.!FP8S@9&$@X`)@!N``8";@!L"<X"A@GN5B(:#A`V"6X```
MEN!D82+@!6`&X&1A)N#ES8S@!@"0X.QM@.`P`)[E`P"0X&0!@.!E02+@#$`$
MX`)`).`$`)#@.$">Y6S!H.$#0)3@`B"4X&5!+.`&0`3@94$DX.8-@.`$()+@
MX$V"X$`@GN4#()+@92&"X&91+.``4`7@#%`EX`4@DN!(4)[E8`&@X0-0E>`,
MP)7@9E$@X`10!>!F427@Y"V"X`7`G.#B78S@4,">Y0/`G.!FP8S@9&$@X`)@
M!N``8";@!L"<X%A@GN5B(:#A`V"6X```EN!D82+@!6`&X&1A)N#ES8S@!@"0
MX.QM@.!@`)[E`P"0X&0!@.!E02+@#$`$X`)`).`$`)#@:$">Y6S!H.$#0)3@
M`B"4X&5!+.`&0`3@94$DX.8-@.`$()+@X$V"X'`@GN4#()+@92&"X&91+.``
M4`7@#%`EX`4@DN!X4)[E8`&@X0-0E>`,P)7@9E$@X`10!>!F427@Y"V"X`7`
MG.#B78S@@,">Y0/`G.!FP8S@9&$@X`)@!N``8";@!L"<X.5MC."(P)[E8B&@
MX0/`G.```)S@9,$BX`7`#.!DP2S@#`"0X.;-@."0`)[E`S"0X&4!(N`&``#@
M`@`@X&0Q@^``,)/@[*V#X)@`GN4L.)_E9F&@X0,`D."@0)[E`B"0X&4!)N`,
M`"#@`""2X`,`E.!E`8#@ZDV"X*A0GN5L(2;@"B`BX`(`D.!J(:#A`U"5X+"@
MGN4&4)7@;&$BX`1@)N#D#8#@!E"5X`-@FN!L88;@N*">Y>#-A>!D42+@`%`E
MX`5@EN!@`:#A`U":X`)0E>#`H)[E["V&X&1A(.`,8";@!E"5X`-@FN!D88;@
MR*">Y6Q!(.`"0"3@XEV%X`1@EN!B(:#A`T":X```E.#0H)[E;$$BX`5`).`$
M0)#@`P":X.5MAN#8H)[E;`&`X&7!(N`&P"S@YDV$X`P`D.!F8:#A`\":X`(@
MG.#@H)[E9<$FX`3`+.`,P)+@`R":X.0-@.#HH)[E92&"X&11)N``4"7@X,V,
MX`4@DN!@`:#A`U":X`90E>#XH)[E\&">Y63A(.`,X"[@["V"X`[@E>#B78[@
M`V"6X&SA(.!D08;@`N`NX`[@E.!B(:#A`T":X`!`E.`889WE;`$BX`4`(.#E
M[8[@``"4X`-@EN#N38#@;,&&X&4!(N`@89WE#@`@X```G.!NX:#A`V"6X`(@
MEN!EP2[@*&&=Y03`+.#D#8#@#,"2X`,@EN!E(8+@,&&=Y>!=C.!DP2[@`,`L
MX`S`DN!@`:#A`V"6X.4MC.`.X);@9,$@X#AAG>4%P"S@#,">X`/@EN!DX8[@
M0&&=Y65!(.`"0"3@XLV,X`3@GN!B(:#A`V"6X```EN!E02+@2&&=Y0Q`).#L
M[8[@4*&=Y01`D.`#`);@[#6?Y6QA(N!E`8#@#F`FX&Y1H.'N383@!F"0X&SA
MA>$#`)K@`@"0X%BAG>7D+8;@!.`.X&QA!>`&X([A#N"0X`.@FN!D`87A9&$%
MX&S!BN`"``#@8*&=Y08`@.'B[8[@#`"0X&(AH.$#P)K@!<"<X&11@N%D80+@
M:*&=Y0Y0!>`&4(7A[@V`X`Q0E>`#H)K@;L&"X6YA`N!D08K@`,`,X'"AG>4&
MP(SAX%V%X`1`G.!@`:#A`\":X`+`G.#E+83@;D&`X6YA`.!XH9WE!4`$X`9`
MA.$,0)3@`Z":X&7!@.%E80#@;N&*X`+`#."`H9WE!L",X>)-A.`.X)S@8B&@
MX0/`FN``P)S@Y`V.X&7A@N%E80+@B*&=Y03@#N`&X([A#.">X`.@FN!DP8+A
M9&$"X&51BN``P`S@D*&=Y0;`C.'@[8[@!5"<X&`!H.$#P)K@`L"<X.XMA>!D
M48#A9&$`X)BAG>4.4`7@!E"%X0Q0E>`#H)K@;L&`X6YA`.!D08K@`L`,X*"A
MG>4&P(SAXEV%X`1`G.!B(:#A`\":X`#`G.#E#83@;D&"X6YA`N"HH9WE!4`$
MX`9`A.$,0)3@`Z":X&7!@N%E80+@;N&*X`#`#."PH9WE!L",X>!-A.`.X)S@
M8`&@X0/`FN`"P)S@Y"V.X&7A@.%E80#@N*&=Y03@#N`&X([A#.">X`.@FN!D
MP8#A9&$`X&51BN`"P`S@P*&=Y0;`C.'B[8[@!5"<X&(AH.$#P)K@`,"<X.X-
MA>!D48+AR*&=Y61A`N`.4`7@!E"%X0Q0E>`#H)K@;L&"X6YA`N!D08K@`,`,
MX-"AG>4&P(SAX%V%X`1`G.!@`:#A`\":X`!@H.,"P)S@Y2V$X&Y!@.$%0`3@
M!&"!Y0Q@@>448('E'&"!Y6YA`.#8H9WE!D"$X0Q`E.!EP8#A`Z":X&5A`.`"
MP`S@;N&*X`;`C.'@H9WEXDV$X`[`G.!B(:#AY.V,X`.@FN!EP8+A96$"X```
MFN`$P`S@Z*&=Y0;`C.$`P)S@`Z":X&0!@N'H,I_E9&$"X&51BN`.``#@\*&=
MY08`@.'NS8S@!0"0X&[AH.$#4)K@`E"5X/AAG>5D(2[@#"`BX.P-@.`"()7@
M`V"6X.!=@N!D08;@;"$NX`!BG>4`("+@`B"4X&`!H.$#0);@#D"4X`ABG>5L
MX2#@!>`NX`[@E.`#0);@Y2V"X!!BG>5L083@9<$@X`+`+.#B[8[@#,"4X&(A
MH.$#0);@`$"4X!ABG>5E`2+@#@`@X.[-C.```)3@`T"6X&5!A.`@8IWE[%V`
MX&X!(N`,`"#@``"4X&S!H.$#0);@`D"4X"ABG>5N(2S@!2`BX.4-@.`"()3@
M`V"6X.!-@N!NX8;@92$LX#!BG>4`("+@`B">X&`!H.$#X);@#.">X#ABG>5E
MP2#@!,`LX.0M@N`,P)[@`^"6X&7ACN!`8IWEXEV,X&3!(.`"P"S@#,">X&(A
MH.$#X);@`.">X$ABG>5D`2+@!0`@X.7-C.```)[@`^"6X&3ACN!08IWE[$V`
MX&4!(N`,`"#@``">X&S!H.$#X);@`N">X%ABG>5E(2S@!"`BX.0-@.`"()[@
M`^"6X&7ACN!@8IWEX%V"X&0A+.``("+@`B">X&`!H.$#X);@#.">X&ABG>5D
MP2#@!<`LX.4M@N`,P)[@`^"6X&3ACN!P8IWEXDV,X&7!(.`"P"S@#,">X&(A
MH.$#X);@`.">X'ABG>5E`2+@!``@X```GN`#X);@Y,V,X&7ACN!D82+@@%*=
MY0Q@)N#L#8#@!N">X&S!H.$#4)7@`B"5X&1A+."(4IWE`&`FX`8@DN`#,)7@
MX.V.X&"1B>`(,)/@8`$LX`X`(.!D,8/@`#"3X.XM@N#B/8/@;G&'X`L@DN`@
M`)'E&)"!Y1!P@>4`,('E"""!Y5`@G^4X,)_E`B"/X`#`G.``8*#C(,"!Y21@
M@>4#,)+G`""3Y90RG>4"(#/@`#"@XP$``!JGWXWB\(^]Z"GS_^M09```&`$`
M`)EY@EJAZ]ENW+P;C];!8LHP6````<J@XW!`+>D,P$W@\`^,Y8``H.,9\__K
M5%"/XM!`Q>$`(*#C\$#`X4Q0C^+00,7A>""`Y?A`P.%$4(_BT$#%X?!!P.%`
M4(_BT$#%X?A!P.$\4(_BT$#%X?!"P.$`0*#C`%"@X_A"P.'P0\#A<("]Z```
MH.$!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,``````<J@
MX_!'+>D,P$W@X`^,Y2@PD.4"H*#ABL&#X"P@D.4#`%SA`#"@XP(@T^``4*#A
M,""0Y0%PH.$T$)#ER@^@X0$``"H!()+B`!"AXBPPA>6J/J#A@#&#X0(PD^"@
M'J'@>`"5Y2C`A>4``%#C.("%`C`PA>4T$(7E&@``&C\`6N,2``#:*F.@X4"0
M2N('0*#A`:!&X@9CA^`$$*#A0""@XP@`H.&M\O_K0$"$X@4`H.&(_/_K!@!4
MX?;__QH*K6K@0'"'X@JCB>`_D,GC!W")X`H@H.$'$*#A"`"@X9_R_^MXH(7E
M\(>]Z$!@8.(*`%;A"F"@H3B`A>(``(C@!B"@X0<0H.&5\O_K>#"5Y0,PAN!`
M`%/C>#"%Y?"'O1@%`*#A!J!*X`9PA^!J_/_KTO__Z@'*H./P02WI#,!-X.@/
MC.4H,)'E`4"@X6,H(^`P$)'E(B2@X?\LPN-C="+@82@AX*,QH.$B)*#A/S`#
MXO\LPN-A9"+@`2"#XCB`A.)_$.#C.`!2XP!0H.$#$,CG`@"(X#P``-I`(&+B
M`!"@XTCR_^L$`*#A2_S_ZS@@H.,`$*#C"`"@X4+R_^L$`*#A<&"$Y71PA.5#
M_/_K`S#4Y0`PQ>6R,-3A`3#%Y0`PE.4$`*#A(S2@X0(PQ>4`,)3E`S#%Y0LP
MU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4
MX0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48,)3E
M(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(PQ>4@
M,)3E$S#%Y?!!O>@=\O_J."!BX@`0H.,+\O_KQ___Z@\*X.,?\$#B"#"?Y0,P
MC^``,)/E7O+_ZM!5```(0"WI"("]Z`$``@`^````00````P```!!````$0``
M`$$````G````00```#8```!!`````P```$$````&````00```!4```!!````
M#P```$$````.````00```"8```!!````$P```$$````I````00````(```!!
M````&0```$$````*````00````L```!!```````````````E<R\E<P```"]P
M<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?
M5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU
M3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!
M3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%2
M7T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)
M4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"
M4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860`
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`
M````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T52
M3D%-10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*
M0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S
M971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`]
M(#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?
M<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S
M(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@
M(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI
M;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E
M='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U
M<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@
M)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@
M)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN
M(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE
M)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D
M8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?
M1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@
M9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E
M(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N
M92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD[
M"FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O
M=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A
M<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN
M9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`[
M"FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C
M86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M
M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F
M:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT
M<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T
M96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH`<&5R;'AS:2YC`````$-!0TA%```^````00````P```!!````$0``
M`$$````G````00```#8```!!`````P```$$````&````00```!4```!!````
M#P```$$````.````00```"8```!!````$P```$$````I````00````(```!!
M````&0```$$````*````00````L```!!```````````````4B_]_`0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````M!@``$P8```!````(P,```$````S`P```0``
M`#T#```,````G!$```T````\2@``&0```,"=```;````!````!H```#$G0``
M'`````0```#U_O]OK`$```4````8"0``!@```)@"```*````L@0```L````0
M````%0`````````#````T)X```(```#8`0``%````!$````7````Q`\``!$`
M``#L#@``$@```-@````3````"````!X````(````^___;P$```C^__]OG`X`
M`/___V\"````\/__;\H-``#Z__]O#@``````````````````````````````
M``````````````````````````#(G0````````````"H$0``J!$``*@1``"H
M$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1
M``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$`
M`*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``
MJ!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H
M$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$``*@1``"H$0``J!$`````
M````````````````````````````````````````````````````````````
M``````"`%`````````2@```*4$%2+G!M"@`````@3@``-$L```````#T2P``
M^$L``!1.```\2P``'$X`````````3@``"$X````````H3@``1T-#.B`H1&5B
M:6%N(#$T+C(N,"TV*2`Q-"XR+C``02H```!A96%B:0`!(`````4U5$4`!@0(
M`0D!$@03`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG
M;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#L````
M!0`````````$````!````#X````+`````@```)@"``"8`@``@`8```8````#
M````!````!````!&`````P````(````8"0``&`D``+($``````````````$`
M````````3@```/___V\"````R@T``,H-``#0````!0`````````"`````@``
M`%L```#^__]O`@```)P.``"<#@``4`````8````"````!`````````!J````
M"0````(```#L#@``[`X``-@````%``````````0````(````<P````D```!"
M````Q`\``,0/``#8`0``!0```!4````$````"````'P````!````!@```)P1
M``"<$0``#```````````````!`````````!W`````0````8```"H$0``J!$`
M`-@"``````````````0````$````@@````$````&````@!0``(`4``"\-0``
M```````````0`````````(@````!````!@```#Q*```\2@``"```````````
M````!`````````".`````0````(```!$2@``1$H``/A!``````````````0`
M````````E@````$``'""````/(P``#R,```(````#0`````````$````````
M`*$````!`````@```$2,``!$C```!```````````````!`````````"K````
M#@````,```#`G0``P(T```0```````````````0````$````MP````\````#
M````Q)T``,2-```$```````````````$````!````,,````&`````P```,B=
M``#(C0``"`$```8`````````!`````@```#,`````0````,```#0G@``T(X`
M`#`!``````````````0````$````T0````$````#`````*````"0``!(````
M```````````$`````````-<````(`````P```$B@``!(D```%```````````
M````!`````````#<`````0```#``````````2)```!X```````````````$`
M```!````Y0````,``'```````````&:0```K```````````````!````````
I``$````#``````````````"1D```]0```````````````0``````````
